@@ -6,6 +6,9 @@ jinja2 template generator
 """
 
 import os
+import io
+import re
+import mmap
 from jinja2 import Environment, FileSystemLoader, \
     ChoiceLoader, FunctionLoader, TemplateNotFound, \
     StrictUndefined
@@ -152,8 +155,9 @@ class Templategen:
             if self.debug:
                 self.log.dbg('using \"magic\" for filetype identification')
         except ImportError:
+            # fallback
             _, filetype = utils.run(['file', '-b', '--mime-type', src],
-                                    raw=False, debug=self.debug)
+                                    debug=self.debug)
             if self.debug:
                 self.log.dbg('using \"file\" for filetype identification')
             filetype = filetype.strip()
@@ -244,16 +248,19 @@ class Templategen:
         """test if file pointed by path is a template"""
         if not os.path.isfile(path):
             return False
+        if os.stat(path).st_size == 0:
+            return False
+        markers = [BLOCK_START, VAR_START, COMMENT_START]
+        patterns = [re.compile(marker.encode()) for marker in markers]
         try:
-            with open(path, 'r') as f:
-                data = f.read()
+            with io.open(path, "r", encoding="utf-8") as f:
+                m = mmap.mmap(f.fileno(), 0, access=mmap.ACCESS_READ)
+                for pattern in patterns:
+                    if pattern.search(m):
+                        return True
         except UnicodeDecodeError:
             # is binary so surely no template
             return False
-        markers = [BLOCK_START, VAR_START, COMMENT_START]
-        for marker in markers:
-            if marker in data:
-                return True
         return False
 
     def _debug_dict(self, title, elems):
